<?php

namespace DSERS_WOO_ALI\Admin;

class DSERS_WOO_ALI_ADMIN_Resource
{
	private $plugin;

	public function __construct(\DSERS_WOO_ALI\DSERS_WOO_ALI_Plugin $plugin)
	{
		$this->plugin = $plugin;
	}

	/**
	 * Defines a list of strings used in the interface, localized and passed
	 * to JavaScript.
	 *
	 * @return array
	 */
	public function ds_woo_l10nList()
	{
		return array(
			'test' => __(
				'Test',
				'DSers'
			),
		);
	}

	/**
	 * Enqueues the plugin script.
	 *
	 * @param string $hook The current admin page.
	 * @return void
	 */
	public function ds_woo_enqueueScript($hook)
	{
		if ('toplevel_page_dsers' !== $hook) {
			return;
		}

		\wp_enqueue_script(
			'dsers',
			"{$this->plugin->ds_woo_getResourcesURL()}js/app.js",
			array(),
			$this->plugin->ds_woo_getVersion()
		);

		$scriptData = array(
			'ajaxUrl' => admin_url('admin-ajax.php'),
			'nonces' => array(
				'getRequireStatus' => wp_create_nonce('dsers-get-site-status-nonce'),
				'getPluginStatus' => wp_create_nonce('dsers-get-plugin-status-nonce'),
				'disconnectdsersNonce' => wp_create_nonce('dsers-disconnect-nonce'),
				'saveShopUrlNonce' => wp_create_nonce('dsers-save-shop-url-nonce'),
				'directSignup' => wp_create_nonce('dsers-direct-signup-nonce'),
				'removeStoreAuthorizationKeyFromRequest' => wp_create_nonce('dsers-remove-store-authorization-key-nonce'),
			),
			'l10n' => $this->ds_woo_l10nList(),
			'assetsSrcUrl' => $this->plugin->ds_woo_getResourcesURL(),
			'assetsUrl' => $this->plugin->ds_woo_getResourcesURL(),
			'storeUrl' => get_site_url(),
			'shopUrl' => get_option('dsers_shop_url', ''),
			'adminUrl' => get_admin_url(null, 'admin.php?page=dsers'),
			'authToken' => get_option('dsers_auth_token', ''),
			'userId' => get_option('dsers_user_id', '')
		);

		wp_localize_script(
			'dsers',
			'DsersConfig',
			$scriptData
		);
	}

	/**
	 * Enqueue all styles needed on the Backend.
	 *
	 * @param string $hook The current admin page.
	 * @return void
	 */
	public function ds_woo_enqueueStyles($hook)
	{
		if ('toplevel_page_dsers' !== $hook) {
			return;
		}

		\wp_enqueue_style(
			'dsers',
			"{$this->plugin->ds_woo_getResourcesURL()}css/app.css",
			array(),
			$this->plugin->ds_woo_getVersion()
		);
	}

	/**
	 * Registeres and enqueues assets.
	 *
	 * @return void
	 */
	public function run()
	{
		add_action('admin_enqueue_scripts', array($this, 'ds_woo_enqueueStyles'));
		add_action('admin_enqueue_scripts', array($this, 'ds_woo_enqueueScript'));
	}
}
