<?php

namespace DSERS_WOO_ALI\Common;

use DSERS_WOO_ALI\Common\DSERS_WOO_ALI_COMMON_Plugin as Plg;

class DSERS_WOO_ALI_COMMON_Requirements {

    public static function ds_woo_checkSSL() {
        if ( !isset($_SERVER['HTTPS']) || empty($_SERVER['HTTPS']) || 'on' !== strtolower($_SERVER['HTTPS']) ) {
			return array(
				'title' => __('SSL Connection', 'dsers'),
				'pass' => false,
				'reason' => __('You are not using a SSL connection', 'dsers'),
				'solution' => __(
					'Please set up a HTTPS certificate to use DSers.'
				),
			);
		}

		return array(
			'title' => __('SSL Connection', 'dsers'),
			'pass' => true,
		);
    }

    public static function ds_woo_checkPermalinksStatus() {
        if (get_option('permalink_structure','') === '') {
            return array(
				'title' => __('Permalinks', 'dsers'),
				'pass' => false,
				'reason' => __(
					'Permalinks set to "Plain"',
					'dsers'
				),
				'solution' => __(
					'Set permalinks to anything other than "Plain" in Settings > Permalinks',
					'dsers'
				),
			);
        }

        return array(
			'title' => __('Permalinks', 'dsers'),
			'pass' => true,
		);
    }

    public static function ds_woo_checkWoocommerceStatus() {
        if (!function_exists('wc')) {
			return array(
				'title' => __('WooCommerce', 'DSers'),
				'pass' => false,
				'reason' => __('WooCommerce plugin is not activated', 'DSers'),
				'solution' => __(
					'Please install and activate the WooCommerce plugin',
					'DSers'
				),
			);
		}

		if (!version_compare(wc()->version, '4.0', '>=')) {
			return array(
				'title' => __('WooCommerce', 'DSers'),
				'pass' => false,
				'reason' => __(
					'WooCommerce plugin is out of date, version >= 2.6 is required',
					'DSers'
				),
				'solution' => __(
					'Please update your WooCommerce plugin',
					'DSers'
				),
			);
		}

		return array(
			'title' => __('WooCommerce', 'DSers'),
			'pass' => true,
		);
    }

    public static function ds_woo_checkWordpressStatus() {
        if (!version_compare(get_bloginfo('version'), '4.4', '>=')) {
			return array(
				'title' => __('WordPress', 'DSers'),
				'pass' => false,
				'reason' => __(
					'WordPress is out of date, version >= 4.4 is required',
					'DSers'
				),
				'solution' => __(
					'Please update your WordPress installation',
					'DSers'
				),
			);
		}

		return array(
			'title' => __('WordPress', 'DSers'),
			'pass' => true,
		);
    }

    public static function ds_woo_checkSiteURLStatus() {
        $host = parse_url( get_home_url(), PHP_URL_HOST );
        return array(
			'title' => __('Plugin check', 'dsers'),
            'pass' => false,
            'solution' => __(
                $host
            ),
		);
    }

    public static function ds_woo_checkPluginBlackStatus() {
        $plugins = get_loaded_extensions();
        if (in_array("stopbadbots",$plugins)) {
            return array(
				'title' => __('Pugin Error', 'dsers'),
				'pass' => false,
				'reason' => __('', 'dsers'),
				'solution' => __(
					'Please disable stopbadbots or add ip: 128.22.22.22 to whitlist to use DSers.'
				),
			);
        }

        if (in_array("woo-multi-currency",$plugins)) {
            return array(
				'title' => __('Pugin Error Woo mul', 'dsers'),
				'pass' => false,
				'reason' => __('', 'dsers'),
				'solution' => __(
					'Please disable stopbadbots or add ip: 128.22.22.22 to whitlist to use DSers.'
				),
			);
        }

        return array(
			'title' => __('Plugin check', 'dsers'),
			'pass' => true,
		);
    }

    public static function ds_woo_checkCurl() {
        if (!in_array('curl', get_loaded_extensions())) {
			return array(
				'title'  => __('PHP cURL', 'dsers'),
				'pass'   => false,
				'reason' => __('PHP cURL seems to be disabled or not installed on your server.', 'dsers'),
				'solution' => __('Please activate cURL to use the dsers plugin. <br>')
			);
		}

		return array(
			'title' => __('PHP cURL', 'dsers'),
			'pass' => true,
		);
    }

	public static function ds_woo_partnerLink() // define( 'DSers_Partner_Link', '' )
	{
		$dsers_partner_link = '';
		if (defined('DSers_Partner_Link')) {
			$dsers_partner_link = constant('DSers_Partner_Link');
		}
		return array(
			'title' => __('Partner Link', 'dsers'),
			'link' => $dsers_partner_link,
		);
	}

	public static function ds_woo_getRequirementsStatus()
	{
		return array(
			'wordpress' => self::ds_woo_checkWordpressStatus(),
			'woocommerce' => self::ds_woo_checkWoocommerceStatus(),
			'ssl' => self::ds_woo_checkSSL(),
			'permalinks' => self::ds_woo_checkPermalinksStatus(),
			'plugin' => self::ds_woo_checkPluginBlackStatus(),
			'curl' => self::ds_woo_checkCurl(),
			'status' => Plg::ds_woo_isReadyConnected(),
			'partner' => self::ds_woo_partnerLink(),
		);
	}
}
